<?php
// require_once __DIR__ . '/config.php';

use Foxdb\DB;
use Foxdb\Schema;
use PHPUnit\Framework\TestCase;

class SchemaTest extends TestCase
{

    public function testDropOldTestTables()
    {
        (new Schema('users'))->drop();
        (new Schema('books'))->drop();
        (new Schema('categorys'))->drop();


        $tables = DB::query('SHOW TABLES;', [], true);
        $this->assertCount(0, $tables);
    }

    public function testCreatedTables()
    {

        $table = new Schema('users');
        $table->id();
        $table->string('name')->utf8mb4();
        $table->string('phone');
        $table->string('fax');
        $table->boolean('status');
        $table->integer('age', 3);
        $table->dateTime('register')->nullable();
        $table->timestamps();
        $table->create();

        $table = new Schema('books');
        $table->id();
        $table->string('code');
        $table->integer('user_id');
        $table->string('title')->utf8mb4();
        $table->text('text')->utf8mb4();
        $table->integer('amount');
        $table->integer('price');
        $table->timestamps();
        $table->create();


        $table = new Schema('categorys');
        $table->id();
        $table->string('name')->utf8mb4();
        $table->timestamps();
        $table->create();

        $tables = DB::query('SHOW TABLES;', [], true);
        $this->assertCount(3, $tables);
    }


    public function testAddNewColumnToUsersTable(){
        $table = new Schema('users');
        $res = $table->addColumn()->boolean('active')->after('register')->default(1)->change();

        $columns = DB::query('SHOW COLUMNS FROM `users`', [], true);

        $status = false;
        $check_after = '';
        foreach($columns as $column){
            if($column->Field == 'active' && $check_after == 'register'){
                $status = true;
                break;
            }
            $check_after = $column->Field;
        }

        $this->assertTrue($status);
    }


    public function testRenameColumn(){
        $table = new Schema('users');
        $table->renameColumn('fax')->string('email', 150)->nullable()->change();

        $columns = DB::query('SHOW COLUMNS FROM `users`', [], true);

        $status = false;

        foreach($columns as $column){
            if($column->Field == 'email'){
                $status = true;
                break;
            }
        }

        $this->assertTrue($status);
    }

}





